==> com.liferay.layout.content.page.editor.web-1.0.126-sources.jar: com/liferay/layout/content/page/editor/web/internal/workflow/WorkflowUtil.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.layout.content.page.editor.web.internal.workflow;

import com.liferay.petra.function.UnsafeRunnable;
import com.liferay.portal.kernel.service.ServiceContext;
import com.liferay.portal.kernel.service.ServiceContextFunction;
import com.liferay.portal.kernel.workflow.WorkflowThreadLocal;

import java.util.function.Function;

import javax.portlet.ActionRequest;

/**
 * @author Alejandro Tardín
 */
public class WorkflowUtil {

	public static Function<String, ServiceContext> getServiceContextFunction(
		int workflowAction, ActionRequest actionRequest) {

		Function<String, ServiceContext> serviceContextFunction =
			new ServiceContextFunction(actionRequest);

		return serviceContextFunction.andThen(
			serviceContext -> {
				serviceContext.setWorkflowAction(workflowAction);

				return serviceContext;
			});
	}

	public static <E extends Exception> void withoutWorkflow(
			UnsafeRunnable<E> unsafeRunnable)
		throws E {

		boolean workflowEnabled = WorkflowThreadLocal.isEnabled();

		WorkflowThreadLocal.setEnabled(false);

		try {
			unsafeRunnable.run();
		}
		finally {
			WorkflowThreadLocal.setEnabled(workflowEnabled);
		}
	}

}

==> com.liferay.layout.content.page.editor.web-3.0.174-sources.jar: com/liferay/layout/content/page/editor/web/internal/workflow/WorkflowUtil.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.layout.content.page.editor.web.internal.workflow;

import com.liferay.petra.function.UnsafeRunnable;
import com.liferay.petra.function.UnsafeSupplier;
import com.liferay.portal.kernel.service.ServiceContext;
import com.liferay.portal.kernel.service.ServiceContextFunction;
import com.liferay.portal.kernel.workflow.WorkflowThreadLocal;

import java.util.function.Function;

import javax.portlet.ActionRequest;

/**
 * @author Alejandro Tardín
 */
public class WorkflowUtil {

	public static Function<String, ServiceContext> getServiceContextFunction(
		int workflowAction, ActionRequest actionRequest) {

		Function<String, ServiceContext> serviceContextFunction =
			new ServiceContextFunction(actionRequest);

		return serviceContextFunction.andThen(
			serviceContext -> {
				serviceContext.setWorkflowAction(workflowAction);

				return serviceContext;
			});
	}

	public static <E extends Exception> void withoutWorkflow(
			UnsafeRunnable<E> unsafeRunnable)
		throws E {

		boolean workflowEnabled = WorkflowThreadLocal.isEnabled();

		WorkflowThreadLocal.setEnabled(false);

		try {
			unsafeRunnable.run();
		}
		finally {
			WorkflowThreadLocal.setEnabled(workflowEnabled);
		}
	}

	public static <T, E extends Exception> T withoutWorkflow(
			UnsafeSupplier<T, E> unsafeSupplier)
		throws E {

		boolean workflowEnabled = WorkflowThreadLocal.isEnabled();

		WorkflowThreadLocal.setEnabled(false);

		try {
			return unsafeSupplier.get();
		}
		finally {
			WorkflowThreadLocal.setEnabled(workflowEnabled);
		}
	}

}
